encode_command

Function encode_command 

pub fn encode_command(args: &[&[u8]]) -> Vec<u8> 
Encode a command as an array of bulk strings.

Every argument is length-prefixed, so no argument can ever be mistaken for another one however strange its bytes are.